#!/bin/sh

# Win32 PostGIS for PostgreSQL build script written by Mark Cave-Ayland
# Copyright 2006

# The dcmms directory should be copied into the postgis-1.x.x directory created
# by untarring the postgis-1.x.x.tar.gz file.
#
# IMPORTANT:
# Before running this script, first apply any patches in the patches/ subdirectory
# to the source tree. If any of the patches make changes to configure.in, you will
# also need to run ./autogen.sh supplied with PostGIS before running this script.

# Installation directories - should be the same as those passed as
# configure --prefix=<DIR> at build time
PGSQL_DIR=/home/mca/pg80/rel
GEOS_DIR=/home/mca/geos/rel-2.2.1
PROJ_DIR=/home/mca/proj/rel-4.4.9
ICONV_DIR=/home/mca/libiconv/rel-1.9.2

# PostGIS JDBC version and path to the PostgreSQL driver JAR file
JDBC_VERSION=1.1.0
JDBC_PGJAR="/c/Program Files/PostgreSQL/8.1/jdbc/postgresql-8.1-404.jdbc2.jar"

# Connection details for regression test database
REG_PGUSER=pg80
REG_PGPORT=5432


# Save current directory
pushd .
cd ..

# First build PostGIS with a reference to ICONV and execute regression tests
echo "Building PostGIS..."
pushd .
CFLAGS="-I$ICONV_DIR/include -L$ICONV_DIR/lib" ./configure --with-pgsql=$PGSQL_DIR/bin/pg_config.exe --with-geos=$GEOS_DIR/bin/geos-config --with-proj=$PROJ_DIR
CFLAGS="-I$ICONV_DIR/include -L$ICONV_DIR/lib" make

echo "Running regression tests..."
PATH=$PGSQL_DIR/bin:$PATH PGUSER=$REG_PGUSER PGPORT=$REG_PGPORT make test

echo "Building topology SQL file..."
cd topology
make
popd

# Build the JDBC2 drivers
echo "Building JDBC2 drivers..."
pushd .
cd jdbc2
CLASSPATH=$JDBC_PGJAR make
popd

# Copy the files we want to a distribution directory
echo "Generating Win32 dist directory..."
rm -rf win32dist
mkdir win32dist
cd win32dist

## bin directory
mkdir bin

cp $GEOS_DIR/bin/libgeos-2.dll bin
cp $GEOS_DIR/bin/libgeos_c-1.dll bin
cp $PROJ_DIR/lib/libproj.dll bin

cp ../loader/pgsql2shp.exe bin
cp ../loader/shp2pgsql.exe bin

## lib directory
mkdir lib

cp ../lwgeom/liblwgeom.dll lib

## doc directory
mkdir -p doc/contrib/html

cp ../README.postgis doc/contrib
cp ../loader/README.shp2pgsql doc/contrib
cp ../loader/README.pgsql2shp doc/contrib
cp ../doc/html/postgis.html doc/contrib/html
cp ../doc/html/style.css doc/contrib/html

## share directory
mkdir -p share/contrib/postgis

cp ../lwpostgis.sql share/contrib
cp ../spatial_ref_sys.sql share/contrib

cp ../utils/create_undef.pl share/contrib/postgis
cp ../utils/postgis_restore.pl share/contrib/postgis
cp ../utils/postgis_proc_upgrade.pl share/contrib/postgis
cp ../lwpostgis_upgrade.sql share/contrib/postgis

mkdir -p share/contrib/postgis/topology
cp ../topology/README share/contrib/postgis/topology/
cp ../topology/topology.sql share/contrib/postgis/topology/

## jdbc directory
mkdir jdbc

cp ../jdbc2/postgis_$JDBC_VERSION.jar jdbc


# Strip any DLL and EXE files in the distribution tree
find -name *.dll | xargs strip
find -name *.exe | xargs strip

# Pop directory
popd

# Generate the .nsh include files by scanning the directories
echo "Generating NSIS file lists for win32dist distribution directory..."
./geninputfiles.sh > inputfiles.nsh
./genuninstallfiles.sh > uninstallfiles.nsh

# Completed
echo "Done. The complete distribution can be found in the ../win32dist/ directory."
